Method: ActiveAdmin::ResourceController::DataAccess#find_collection
- Defined in:
- lib/active_admin/resource_controller/data_access.rb
#find_collection(options = {}) ⇒ ActiveRecord::Relation (protected)
Does the actual work of retrieving the current collection from the db. This is a great method to override if you would like to perform some additional db # work before your controller returns and authorizes the collection.
56 57 58 59 60 61 62 |
# File 'lib/active_admin/resource_controller/data_access.rb', line 56 def find_collection( = {}) collection = scoped_collection collection_applies().each do |applyer| collection = send("apply_#{applyer}", collection) end collection end |