Method: ActiveAdmin::ResourceController::DataAccess#scoped_collection
- Defined in:
- lib/active_admin/resource_controller/data_access.rb
#scoped_collection ⇒ Object (protected)
Override this method in your controllers to modify the start point of our searches and index.
This method should return an ActiveRecord::Relation object so that the searching and filtering can be applied on top
Note, unless you are doing something special, you should use the scope_to method from the Scoping module instead of overriding this method.
73 74 75 |
# File 'lib/active_admin/resource_controller/data_access.rb', line 73 def scoped_collection end_of_association_chain end |